@@ -74,7 +74,7 @@
     <message>
         <location filename="../mainwindow.ui" line="79"/>
         <source>Home Directory</source>
-        <translation>ホームディレクトリー</translation>
+        <translation>ホームディレクトリ</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="87"/>
@@ -104,7 +104,7 @@
     <message>
         <location filename="../mainwindow.ui" line="185"/>
         <source>Edit properties of the selected item</source>
-        <translation type="unfinished"></translation>
+        <translation>選択したアイテムのプロパティを編集する</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="158"/>
@@ -129,7 +129,7 @@
     <message>
         <location filename="../mainwindow.ui" line="182"/>
         <source>Properties</source>
-        <translation>プロパティー</translation>
+        <translation>プロパティ</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="194"/>
@@ -176,7 +176,7 @@
     <message>
         <location filename="../mainwindow.cpp" line="210"/>
         <source>Are you sure you want to set a empty password?</source>
-        <translation>空白のパスワードを設定しますか?</translation>
+        <translation>パスワードを空にしますか?</translation>
     </message>
 </context>
 <context>
@@ -239,7 +239,7 @@
     <message>
         <location filename="../userdialog.ui" line="132"/>
         <source>Home directory:</source>
-        <translation>ホームディレクトリー:</translation>
+        <translation>ホームディレクトリ:</translation>
     </message>
     <message>
         <location filename="../userdialog.cpp" line="120"/>
@@ -257,12 +257,12 @@
     <message>
         <location filename="../usermanager.cpp" line="227"/>
         <source>lxqt-admin-user</source>
-        <translation type="unfinished"></translation>
+        <translation>LXQt ユーザー管理</translation>
     </message>
     <message>
         <location filename="../usermanager.cpp" line="228"/>
         <source>&lt;strong&gt;Action (%1) failed:&lt;/strong&gt;&lt;br/&gt;&lt;pre&gt;%2&lt;/pre&gt;</source>
-        <translation type="unfinished"></translation>
+        <translation>&lt;strong&gt;アクション(%1)が失敗:&lt;/strong&gt;&lt;br/&gt;&lt;pre&gt;%2&lt;/pre&gt;</translation>
     </message>
 </context>
 </TS>
